/**
 * Copyright (C) 2006 OQube 
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *  
 * author: Arnaud Bailly - abailly AT oqube DOT com
 * created: 14 juin 2006
 */
package speculoos.core;

import java.util.Collection;

/**
 * An interface for objects that may collect several other 
 * mapper objects.
 * 
 * This interface is a simple way to collect and retrieve sets 
 * of mappers in different contexts.
 * 
 * @author nono
 *
 */
public interface MapperCollector {

	/**
	 * adds a new mapper to this collector.
	 * 
	 * @param m thu mapper to add.
	 */
	void addMapper(Mapper m);
	
	/**
	 * Add a whole collection of mappers to this collector.
	 * 
	 * @param col a Collection<Mapper> instance.
 	 */
	void addMappers(Collection col);
	
	/**
	 * Return all the mappers collected so far.
	 * 
	 * @return a Collection<Mapper> instance. This collection is owned 
	 * by this object and my not be modified by caller.
	 */
	Collection getMappers();
	
}
