/*---------------------------------------------------------------------------
 * 2005 NORSYS
 * main author : nono
 *
 * This software is a computer program whose purpose is to provide abstraction
 * for accessing directory data sources within java applications.
 *
 * This software is governed by the CeCILL  license under French law and
 * abiding by the rules of distribution of free software.  You can  use, 
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info". 
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability. 
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or 
 * data to be ensured and,  more generally, to use and operate it in the 
 * same conditions as regards security. 
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 *
 * Created on Oct 24, 2005
 * --------------------------------------------------------------------------*/
package speculoos.core;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

/**
 * A mapper implementation for creating tuple of mappers.
 * <p>
 * An UnionMapper is used to aggregate the result of several 
 * mappers in one ordered result. The method  
 * @author nono
 * @version $Id$
 */
public class UnionMapper implements Mapper {

    private List mappers = new ArrayList();
    
    private String name = "_union";
    
    /**
     * Adds a new mapper to this union. 
     * The mappers's map result will be appended at the 
     * end of the union.
     * 
     * @param m the mapper to add
     */
    public void add(Mapper m) {
        this.mappers.add(m);
    }
    
    /**
     * Remove all mappers associatd with this union mapper.
     *
     */
    public void clear() {
        this.mappers.clear();
    }
    
    /**
     * Implementation of map for Union.
     * This implementation works as follows:
     * <ul>
     * <li>Each mapper in the <code>mappers</code> property is invoked in the same 
     * environment with the same input, </li>
     * <li>The result of each mapper's map method is aggregated into a Collection
     * which is returned by this method. 
     * </ul>
     * This mapper is a simple way to group several mappers into a signle 
     * invocation.
     * 
     * @see speculoos.core.Mapper#map(java.lang.Object, java.util.Map)
     */
    public Object map(Object input, Map param) throws MapperException {
        List res = new ArrayList(mappers.size());
        for(Iterator i = mappers.iterator();i.hasNext();) {
            Mapper map = (Mapper)i.next();
            res.add(map.map(input,param));
        }
        return res;
    }

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

}
